summaryrefslogtreecommitdiff
path: root/docs/shared_bindings_matrix.py
diff options
context:
space:
mode:
authorLucian Copeland <hierophect@gmail.com>2020-04-23 13:33:41 -0400
committerLucian Copeland <hierophect@gmail.com>2020-04-23 13:33:41 -0400
commit8791ca6af3f5a63d286d9f5c3e26f55a1619ff86 (patch)
tree9709829a960b9f7503783b5ca9899a7b65ae52a0 /docs/shared_bindings_matrix.py
parentd0a210654767677d6d26f1d4d40c378e03e9ca8e (diff)
implement requested changes
Diffstat (limited to 'docs/shared_bindings_matrix.py')
-rw-r--r--docs/shared_bindings_matrix.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/docs/shared_bindings_matrix.py b/docs/shared_bindings_matrix.py
index 0473c5119..d5f838f75 100644
--- a/docs/shared_bindings_matrix.py
+++ b/docs/shared_bindings_matrix.py
@@ -139,9 +139,9 @@ def get_excluded_boards(base):
re_board_chip = re.compile("CHIP_FAMILY\s=\s(\w+)")
chip_keyword = "CHIP_FAMILY"
elif port in ["nrf"]:
- re_board_chip = re.compile("MCU_VARIANT\s=\s(\w+)")
+ re_board_chip = re.compile(r"MCU_VARIANT\s=\s(\w+)")
elif port in ["stm"]:
- re_board_chip = re.compile("MCU_SERIES\s*=\s*(\w+)")
+ re_board_chip = re.compile(r"MCU_SERIES\s*=\s*(\w+)")
chip_keyword = "MCU_SERIES"
port_dir = "ports/{}".format(port)
@@ -175,9 +175,9 @@ def get_excluded_boards(base):
check_dependent_modules = dict()
for module in modules:
board_is_excluded = False
# check if board uses `SMALL_BUILD`. if yes, and current
# module is marked as `FULL_BUILD`, board is excluded
- small_build = re.search("CIRCUITPY_SMALL_BUILD = 1", contents)
+ small_build = re.search("CIRCUITPY_FULL_BUILD = 0", contents)
if small_build and base[module]["full_build"] == "1":
board_is_excluded = True
@@ -175,9 +175,9 @@ def get_excluded_boards(base):
for module in modules:
board_is_excluded = False
- # check if board uses `SMALL_BUILD`. if yes, and current
+ # check if board turns off `FULL_BUILD`. if yes, and current
# module is marked as `FULL_BUILD`, board is excluded